@@ -12,8 +12,8 @@ from hoppr import __version__
 from hoppr.base_plugins.collector import CollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
 from hoppr.context import Context
-from hoppr.result import Result
 from hoppr.hoppr_types.cred_object import CredObject
+from hoppr.result import Result
 
 
 class CollectDockerPlugin(CollectorPlugin):
@@ -47,7 +47,8 @@ class CollectDockerPlugin(CollectorPlugin):
 
         file_name = urllib.parse.unquote(purl.name) + "_" + purl.version
         target_dir = self.directory_for(purl.type, repo_url, subdir=purl.namespace)
-        destination = "docker-archive:" + os.path.join(target_dir, file_name)
+        target_path = os.path.join(target_dir, file_name)
+        destination = "docker-archive:" + target_path
 
         self.get_logger().info(
             f"Copying docker image from {source_url} to {destination}"
@@ -73,6 +74,11 @@ class CollectDockerPlugin(CollectorPlugin):
                 + f"return_code={proc.returncode}"
             )
             self.get_logger().error(msg)
+            if os.path.exists(target_path):
+                self.get_logger().info(
+                    "Artifact collection failed, deleting file and retrying"
+                )
+                os.remove(target_dir)
             return Result.retry(msg)
 
         return Result.success()
