@@ -353,7 +353,7 @@ class HopprProcessor:  # pylint: disable=too-few-public-methods
                 self.context.max_processes = self.transfer.content.max_processes
 
             self.get_logger().info(  # pylint: disable=logging-fstring-interpolation
-                f"Beggining Hoppr Process execution, max_processes={self.context.max_processes}"
+                f"Beginning Hoppr Process execution, max_processes={self.context.max_processes}"
             )
             self._collect_metadata()
 
